.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/zostera/django-marina.svg?branch=master
    :target: https://travis-ci.org/zostera/django-marina

Django extensions by Zostera. Use at your own leisure and peril.

Documentation is `available online
<https://django-marina.readthedocs.io/>`_.
